@@ -1,6 +1,6 @@
 from django_socio_grpc import generics
 from django_socio_grpc.decorators import grpc_action
-from fakeapp.serializers import BasicServiceSerializer
+from fakeapp.serializers import BaseProtoExampleSerializer, BasicServiceSerializer
 
 
 class BasicService(generics.GenericService):
@@ -19,7 +19,12 @@ class BasicService(generics.GenericService):
         }
 
         serializer = BasicServiceSerializer(
-            {"user_name": request.user_name, "user_data": user_data, "bytes_example": b"test"}
+            {
+                "user_name": request.user_name,
+                "user_data": user_data,
+                "bytes_example": b"test",
+                "list_of_dict": [{"test": "test"}],
+            }
         )
         return serializer.message
 
@@ -44,6 +49,7 @@ class BasicService(generics.GenericService):
                     "slogan": "Do it better",
                 },
                 "bytes_example": b"test",
+                "list_of_dict": [],
             },
             {
                 "user_name": "fake2",
@@ -53,6 +59,7 @@ class BasicService(generics.GenericService):
                     "slogan": "Do it better2",
                 },
                 "bytes_example": b"test",
+                "list_of_dict": [],
             },
         ]
 
@@ -87,3 +94,11 @@ class BasicService(generics.GenericService):
     )
     async def MixParamWithSerializer(self, request, context):
         pass
+
+    @grpc_action(
+        request=BaseProtoExampleSerializer,
+        response=BaseProtoExampleSerializer,
+        use_response_list=True,
+    )
+    async def TestBaseProtoSerializer(self, request, context):
+        pass
